Index: trunk/source/processes/electromagnetic/lowenergy/include/G4AtomicDeexcitation.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4AtomicDeexcitation.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4AtomicDeexcitation.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4AtomicTransitionManager.hh,v 1.2 ????
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Authors: Elena Guardincerri (Elena.Guardincerri@ge.infn.it)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4AtomicShell.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4AtomicShell.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4AtomicShell.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4AtomicShell.hh,v 1.2 ????
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Authors: Elena Guardincerri (Elena.Guardincerri@ge.infn.it)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4AtomicTransitionManager.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4AtomicTransitionManager.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4AtomicTransitionManager.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4AtomicTransitionManager.hh,v 1.2 ????
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Authors: Elena Guardincerri (Elena.Guardincerri@ge.infn.it)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4AugerData.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4AugerData.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4AugerData.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4AugerData.hh
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Alfonso Mantero (Alfonso.Mantero@ge.infn.it)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4BremsstrahlungCrossSectionHandler.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4BremsstrahlungCrossSectionHandler.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4BremsstrahlungCrossSectionHandler.hh	(revision 1055)
@@ -70,4 +70,8 @@
   ~G4BremsstrahlungCrossSectionHandler();
  
+  G4double GetCrossSectionAboveThresholdForElement(G4double energy,
+                                                   G4double cutEnergy,
+                                                   G4int Z);
+
 protected:
 
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4BremsstrahlungParameters.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4BremsstrahlungParameters.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4BremsstrahlungParameters.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4BremsstrahlungParameters.hh,v 1.10 2006/06/29 19:33:06 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CompositeEMDataSet.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CompositeEMDataSet.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CompositeEMDataSet.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4CompositeEMDataSet.hh,v 1.12 2008/03/17 13:45:25 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeDecrease.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeDecrease.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeDecrease.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionChargeDecrease.hh,v 1.2 2008/07/14 20:47:32 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4CROSSSECTIONCHARGEDECREASE_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeDecreasePartial.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeDecreasePartial.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeDecreasePartial.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionChargeDecreasePartial.hh,v 1.2 2008/07/14 20:47:32 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4CROSSSECTIONCHARGEDECREASEPARTIAL_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeIncrease.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeIncrease.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeIncrease.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionChargeIncrease.hh,v 1.2 2008/07/14 20:47:33 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4CROSSSECTIONCHARGEIncrease_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeIncreasePartial.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeIncreasePartial.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeIncreasePartial.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionChargeIncreasePartial.hh,v 1.2 2008/07/14 20:47:33 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4CROSSSECTIONCHARGEIncreasePARTIAL_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeTransferCH.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeTransferCH.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeTransferCH.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4CrossSectionChargeTransferCH.hh,v 1.3 2008/03/25 16:00:20 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // 
 // Contact Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeTransferExp.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeTransferExp.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionChargeTransferExp.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4CrossSectionChargeTransferExp.hh,v 1.2 2008/03/25 16:00:20 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // 
 // Contact Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionElasticChampion.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionElasticChampion.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionElasticChampion.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionElasticChampion.hh,v 1.1 2008/07/15 19:56:50 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // -------------------------------------------------------------------
 
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionElasticScreenedRutherford.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionElasticScreenedRutherford.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionElasticScreenedRutherford.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4CrossSectionElasticScreenedRutherford.hh,v 1.1 2007/10/12 23:07:10 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // 
 // Contact Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionElasticScreenedRutherfordHE.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionElasticScreenedRutherfordHE.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionElasticScreenedRutherfordHE.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionElasticScreenedRutherfordHE.hh,v 1.1 2008/06/27 20:09:54 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4CROSSSECTIONELASTICSCREENEDRUTHERFORDHE_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionElasticScreenedRutherfordLE.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionElasticScreenedRutherfordLE.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionElasticScreenedRutherfordLE.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionElasticScreenedRutherfordLE.hh,v 1.2 2008/07/14 20:47:33 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4CROSSSECTIONELASTICSCREENEDRUTHERFORDLE_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionExcitationBorn.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionExcitationBorn.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionExcitationBorn.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionExcitationBorn.hh,v 1.2 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4CROSSSECTIONEXCITATIONBORN_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionExcitationBornPartial.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionExcitationBornPartial.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionExcitationBornPartial.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionExcitationBornPartial.hh,v 1.2 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4CROSSSECTIONEXCITATIONBORNPARTIAL_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionExcitationEmfietzoglou.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionExcitationEmfietzoglou.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionExcitationEmfietzoglou.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionExcitationEmfietzoglou.hh,v 1.3 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4CROSSSECTIONEXCITATIONEMFIETZOGLOU_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionExcitationEmfietzoglouPartial.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionExcitationEmfietzoglouPartial.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionExcitationEmfietzoglouPartial.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionExcitationEmfietzoglouPartial.hh,v 1.2 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4CROSSSECTIONEXCITATIONEMFIETZOGLOUPARTIAL_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionExcitationMillerGreenPartial.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionExcitationMillerGreenPartial.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionExcitationMillerGreenPartial.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionExcitationMillerGreenPartial.hh,v 1.2 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4CROSSSECTIONEXCITATIONMILLERGREENPARTIAL_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionHandler.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionHandler.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionHandler.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4CrossSectionHandler.hh,v 1.9 2006/06/29 19:33:10 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationBorn.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationBorn.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationBorn.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4CrossSectionIonisationBorn.hh,v 1.3 2008/12/18 13:01:22 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4CROSSSECTIONIONISATIONBORN_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationBornElectron.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationBornElectron.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationBornElectron.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4CrossSectionIonisationBornElectron.hh,v 1.1 2007/10/15 08:33:25 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // 
 // Contact Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationBornPartial.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationBornPartial.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationBornPartial.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionIonisationBornPartial.hh,v 1.2 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4CROSSSECTIONIONISATIONBORNPARTIAL_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationBornPartialElectron.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationBornPartialElectron.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationBornPartialElectron.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4CrossSectionIonisationBornPartialElectron.hh,v 1.1 2007/10/15 08:33:25 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // 
 // Contact Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationRudd.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationRudd.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationRudd.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionIonisationRudd.hh,v 1.2 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4CROSSSECTIONIONISATIONRUDD_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationRuddPartial.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationRuddPartial.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionIonisationRuddPartial.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionIonisationRuddPartial.hh,v 1.2 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4CROSSSECTIONIONISATIONRuddPARTIAL_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionKill.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionKill.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionKill.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4CrossSectionKill.hh,v 1.1 2007/11/09 20:26:47 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // 
 // Contact Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionPsCreationChampion.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionPsCreationChampion.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionPsCreationChampion.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionPsCreationChampion.hh,v 1.1 2008/07/16 19:01:07 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // -------------------------------------------------------------------
 
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionPsCreationChampionPartial.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionPsCreationChampionPartial.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4CrossSectionPsCreationChampionPartial.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4CrossSectionPsCreationChampionPartial.hh,v 1.1 2008/07/16 19:01:07 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // -------------------------------------------------------------------
 
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4DNACrossSectionDataSet.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4DNACrossSectionDataSet.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4DNACrossSectionDataSet.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4DNACrossSectionDataSet.hh,v 1.6 2008/03/17 13:45:25 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Riccardo Capra <capra@ge.infn.it>
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4DNAGenericIonsManager.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4DNAGenericIonsManager.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4DNAGenericIonsManager.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4DNAGenericIonsManager.hh,v 1.3 2006/06/29 19:34:16 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef   G4DNAGENERICIONSMANAGER_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4DNAProcess.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4DNAProcess.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4DNAProcess.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4DNAProcess.hh,v 1.5 2007/11/09 16:20:04 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author:  Maria Grazia Pia (Maria.Grazia.Pia@ge.infn.it)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4DNAProcess.icc
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4DNAProcess.icc	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4DNAProcess.icc	(revision 1055)
@@ -25,6 +25,6 @@
 //
 //
-// $Id: G4DNAProcess.icc,v 1.11 2007/12/10 16:31:19 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// $Id: G4DNAProcess.icc,v 1.12 2009/01/20 07:50:28 sincerti Exp $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // 
 // Contact Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
@@ -111,6 +111,14 @@
       aParticleChange.ProposeEnergy(0.);
       aParticleChange.ProposeMomentumDirection( 0., 0., 0. );
-      aParticleChange.ProposeLocalEnergyDeposit(track.GetKineticEnergy() + deposit);
-  	
+      
+      if (product.PrimaryParticleIsKilledAndDoNotDepositEnergy())
+      {
+        aParticleChange.ProposeLocalEnergyDeposit(deposit);
+      }
+      else
+      {
+        aParticleChange.ProposeLocalEnergyDeposit(track.GetKineticEnergy() + deposit);
+      }
+      
     }
   else
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4DopplerProfile.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4DopplerProfile.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4DopplerProfile.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4DopplerProfile.hh,v 1.2 2008/03/17 13:45:25 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4DummyFinalState.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4DummyFinalState.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4DummyFinalState.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4DummyFinalState.hh,v 1.2 2007/10/07 12:52:18 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // 
 // Contact Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4EMDataSet.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4EMDataSet.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4EMDataSet.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4EMDataSet.hh,v 1.12 2008/03/17 13:45:25 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateChargeDecrease.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateChargeDecrease.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateChargeDecrease.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4FinalStateChargeDecrease.hh,v 1.2 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4FINALSTATECHARGEDECREASE_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateChargeIncrease.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateChargeIncrease.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateChargeIncrease.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4FinalStateChargeIncrease.hh,v 1.2 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4FINALSTATECHARGEIncrease_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateChargeTransferProton.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateChargeTransferProton.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateChargeTransferProton.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4FinalStateChargeTransferProton.hh,v 1.2 2008/03/25 16:00:20 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // 
 // Contact Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateElasticBrennerZaider.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateElasticBrennerZaider.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateElasticBrennerZaider.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4FinalStateElasticBrennerZaider.hh,v 1.2 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4FINALSTATEELASTICBRENNERZAIDER_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateElasticChampion.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateElasticChampion.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateElasticChampion.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4FinalStateElasticChampion.hh,v 1.1 2008/07/15 19:56:50 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // -------------------------------------------------------------------
 
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateElasticScreenedRutherford.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateElasticScreenedRutherford.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateElasticScreenedRutherford.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4FinalStateElasticScreenedRutherford.hh,v 1.3 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4FINALSTATEELASTICSCREENEDRUTHERFORD_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateExcitationBorn.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateExcitationBorn.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateExcitationBorn.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4FinalStateExcitationBorn.hh,v 1.2 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4FINALSTATEEXCITATIONBORN_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateExcitationEmfietzoglou.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateExcitationEmfietzoglou.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateExcitationEmfietzoglou.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4FinalStateExcitationEmfietzoglou.hh,v 1.2 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4FINALSTATEEXCITATIONEMFIETZOGLOU_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateExcitationMillerGreen.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateExcitationMillerGreen.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateExcitationMillerGreen.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4FinalStateExcitationMillerGreen.hh,v 1.2 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4FINALSTATEEXCITATIONMILLERGREEN_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateIonisationBorn.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateIonisationBorn.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateIonisationBorn.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4FinalStateIonisationBorn.hh,v 1.4 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4FINALSTATEIONISATIONBORN_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateIonisationRudd.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateIonisationRudd.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateIonisationRudd.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4FinalStateIonisationRudd.hh,v 1.4 2008/07/14 20:47:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateKill.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateKill.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateKill.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4FinalStateKill.hh,v 1.1 2007/11/09 20:26:47 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // 
 // Contact Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateProduct.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateProduct.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStateProduct.hh	(revision 1055)
@@ -25,6 +25,6 @@
 //
 //
-// $Id: G4FinalStateProduct.hh,v 1.4 2007/10/15 08:31:49 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// $Id: G4FinalStateProduct.hh,v 1.5 2009/01/20 07:50:28 sincerti Exp $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // 
 // Contact Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
@@ -72,7 +72,10 @@
   void ModifyPrimaryParticle(const G4ThreeVector& direction, G4double energy);
   
+  void DoNotDepositEnergy();
   void KillPrimaryParticle();
- 
+
   G4bool PrimaryParticleIsKilled() const { return killStatus; }
+  
+  G4bool PrimaryParticleIsKilledAndDoNotDepositEnergy() const { return doNotDepositStatus; }
   
   G4bool PrimaryParticleIsModified() const { return isModified; }
@@ -96,4 +99,5 @@
   
   G4bool killStatus;
+  G4bool doNotDepositStatus;
   G4bool isModified;
   G4double localEnergyDeposit;
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStatePsCreationChampion.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStatePsCreationChampion.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4FinalStatePsCreationChampion.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4FinalStatePsCreationChampion.hh,v 1.1 2008/07/16 19:01:07 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // -------------------------------------------------------------------
 
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4FluoTransition.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4FluoTransition.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4FluoTransition.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4FluoTransition.hh,v 1.2 ????
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Elena Guardincerri (Elena.Guardincerri@ge.infn.it)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4IonParametrisedLossModel.icc
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4IonParametrisedLossModel.icc	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4IonParametrisedLossModel.icc	(revision 1055)
@@ -37,5 +37,9 @@
 // First implementation: 10. 11. 2008
 //
-// Modifications:
+// Modifications: 03. 02. 2009 - Bug fix iterators (AL)
+//                11. 03. 2009 - Introduced new table handler (G4IonDEDXHandler)
+//                               and modified method to add/remove tables
+//                               (tables are now built in initialisation phase),
+//                               Minor bug fix in ComputeDEDXPerVolume (AL)
 //
 //
@@ -186,5 +190,5 @@
                     const G4Material* material) {          // Target material
 
-  LossTableList::iterator iter = lossTableList.begin();
+  LossTableList::iterator iter = lossTableList.end();
   LossTableList::iterator iterTables = lossTableList.begin();
   LossTableList::iterator iterTables_end = lossTableList.end();
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4LinInterpolation.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4LinInterpolation.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4LinInterpolation.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4LinInterpolation.hh,v 1.3 2006/06/29 19:35:45 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4LivermoreComptonModel.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4LivermoreComptonModel.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4LivermoreComptonModel.hh	(revision 1055)
@@ -24,7 +24,13 @@
 // ********************************************************************
 //
-// $Id: G4LivermoreComptonModel.hh,v 1.1 2008/10/30 14:16:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// $Id: G4LivermoreComptonModel.hh,v 1.3 2009/04/17 10:29:20 vnivanch Exp $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
+//
+// Author: Sebastien Inserti
+//         30 October 2008
+//
+// History:
+// --------
 
 #ifndef G4LivermoreComptonModel_h
@@ -40,4 +46,5 @@
 #include "G4DopplerProfile.hh"
 #include "G4ForceCondition.hh"
+#include "G4Gamma.hh"
 
 class G4LivermoreComptonModel : public G4VEmModel
@@ -70,7 +77,7 @@
   G4ParticleChangeForGamma* fParticleChange;
 
-  G4double GetMeanFreePath(const G4Track& track, 
-			   G4double previousStepSize, 
-			   G4ForceCondition* condition);
+  //G4double GetMeanFreePath(const G4Track& track, 
+  //			   G4double previousStepSize, 
+  //			   G4ForceCondition* condition);
 private:
 
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4LivermoreGammaConversionModel.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4LivermoreGammaConversionModel.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4LivermoreGammaConversionModel.hh	(revision 1055)
@@ -24,6 +24,6 @@
 // ********************************************************************
 //
-// $Id: G4LivermoreGammaConversionModel.hh,v 1.1 2008/10/30 14:16:34 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// $Id: G4LivermoreGammaConversionModel.hh,v 1.3 2009/04/17 10:29:20 vnivanch Exp $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 
@@ -38,4 +38,5 @@
 #include "G4ForceCondition.hh"
 #include "G4CompositeEMDataSet.hh"
+#include "G4Gamma.hh"
 
 class G4LivermoreGammaConversionModel : public G4VEmModel
@@ -45,5 +46,5 @@
 
   G4LivermoreGammaConversionModel(const G4ParticleDefinition* p = 0, 
-		     const G4String& nam = "LivermoreGammaConversion");
+		     const G4String& nam = "LivermoreConversion");
 
   virtual ~G4LivermoreGammaConversionModel();
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4LivermorePhotoElectricModel.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4LivermorePhotoElectricModel.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4LivermorePhotoElectricModel.hh	(revision 1055)
@@ -24,6 +24,6 @@
 // ********************************************************************
 //
-// $Id: G4LivermorePhotoElectricModel.hh,v 1.1 2008/10/30 14:16:35 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// $Id: G4LivermorePhotoElectricModel.hh,v 1.3 2009/04/17 10:29:20 vnivanch Exp $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 
@@ -48,5 +48,5 @@
 #include "G4ProductionCutsTable.hh"
 #include "G4ForceCondition.hh"
-
+#include "G4Gamma.hh"
 
 class G4LivermorePhotoElectricModel : public G4VEmModel
@@ -56,5 +56,5 @@
 
   G4LivermorePhotoElectricModel(const G4ParticleDefinition* p = 0, 
-		     const G4String& nam = "LivermorePhotoElectric");
+		     const G4String& nam = "LivermorePhElectric");
 
   virtual ~G4LivermorePhotoElectricModel();
@@ -89,8 +89,9 @@
 
   G4ParticleChangeForGamma* fParticleChange;
-
+  /*
   G4double GetMeanFreePath(const G4Track& aTrack, 
 			   G4double previousStepSize, 
 			   G4ForceCondition* condition);
+  */
 private:
 
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4LivermorePolarizedComptonModel.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4LivermorePolarizedComptonModel.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4LivermorePolarizedComptonModel.hh	(revision 1055)
@@ -24,6 +24,6 @@
 // ********************************************************************
 //
-// $Id: G4LivermorePolarizedComptonModel.hh,v 1.1 2008/10/30 14:16:35 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// $Id: G4LivermorePolarizedComptonModel.hh,v 1.3 2009/05/02 15:20:52 sincerti Exp $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 
@@ -40,4 +40,5 @@
 #include "G4DopplerProfile.hh"
 #include "G4ForceCondition.hh"
+#include "G4Gamma.hh"
 
 class G4LivermorePolarizedComptonModel : public G4VEmModel
@@ -71,7 +72,9 @@
   G4ParticleChangeForGamma* fParticleChange;
 
+  /*
   G4double GetMeanFreePath(const G4Track& aTrack, 
 			   G4double previousStepSize, 
 			   G4ForceCondition* condition);
+			   */
 private:
 
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4LivermorePolarizedRayleighModel.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4LivermorePolarizedRayleighModel.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4LivermorePolarizedRayleighModel.hh	(revision 1055)
@@ -24,6 +24,6 @@
 // ********************************************************************
 //
-// $Id: G4LivermorePolarizedRayleighModel.hh,v 1.1 2008/10/30 14:16:35 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// $Id: G4LivermorePolarizedRayleighModel.hh,v 1.3 2009/05/02 15:20:52 sincerti Exp $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 
@@ -36,4 +36,5 @@
 #include "G4LogLogInterpolation.hh"
 #include "G4CompositeEMDataSet.hh"
+#include "G4Gamma.hh"
 
 class G4LivermorePolarizedRayleighModel : public G4VEmModel
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4LivermoreRayleighModel.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4LivermoreRayleighModel.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4LivermoreRayleighModel.hh	(revision 1055)
@@ -24,6 +24,6 @@
 // ********************************************************************
 //
-// $Id: G4LivermoreRayleighModel.hh,v 1.1 2008/10/30 14:16:35 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// $Id: G4LivermoreRayleighModel.hh,v 1.3 2009/04/17 10:29:20 vnivanch Exp $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 
@@ -37,4 +37,5 @@
 #include "G4CompositeEMDataSet.hh"
 #include "G4ForceCondition.hh"
+#include "G4Gamma.hh"
 
 class G4LivermoreRayleighModel : public G4VEmModel
@@ -68,7 +69,4 @@
   G4ParticleChangeForGamma* fParticleChange;
 
-  G4double GetMeanFreePath(const G4Track& aTrack, 
-			   G4double previousStepSize, 
-			   G4ForceCondition* condition);
 private:
 
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4LogLogInterpolation.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4LogLogInterpolation.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4LogLogInterpolation.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4LogLogInterpolation.hh,v 1.6 2008/12/09 13:28:02 sincerti Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyBremsstrahlung.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyBremsstrahlung.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyBremsstrahlung.hh	(revision 1055)
@@ -27,5 +27,5 @@
 // -------------------------------------------------------------------
 // $Id: G4LowEnergyBremsstrahlung.hh,v 1.37 2006/06/29 19:35:55 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: A. Forti
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyCompton.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyCompton.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyCompton.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4LowEnergyCompton.hh,v 1.24 2008/11/04 10:14:00 pandola Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: A. Forti
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyGammaConversion.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyGammaConversion.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyGammaConversion.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4LowEnergyGammaConversion.hh,v 1.15 2006/06/29 19:35:59 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: A. Forti
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyIonisation.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyIonisation.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyIonisation.hh	(revision 1055)
@@ -26,5 +26,5 @@
 // -------------------------------------------------------------------
 // $Id: G4LowEnergyIonisation.hh,v 1.41 2006/06/29 19:36:01 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: A. Forti
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyPhotoElectric.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyPhotoElectric.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyPhotoElectric.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4LowEnergyPhotoElectric.hh,v 1.28 2006/06/29 19:36:03 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: A. Forti
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyPolarizedCompton.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyPolarizedCompton.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyPolarizedCompton.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4LowEnergyPolarizedCompton.hh,v 1.10 2008/05/02 13:04:41 flongo Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // ------------------------------------------------------------
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyPolarizedRayleigh.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyPolarizedRayleigh.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyPolarizedRayleigh.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4LowEnergyPolarizedRayleigh.hh,v 1.5 2006/06/29 19:36:07 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // --------------------------------------------------------------
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyRayleigh.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyRayleigh.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4LowEnergyRayleigh.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4LowEnergyRayleigh.hh,v 1.16 2006/06/29 19:36:09 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // 
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4OrlicLCrossSection.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4OrlicLCrossSection.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4OrlicLCrossSection.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4OrlicLCrossSection.hh,v 1.3 2008/06/03 07:29:15 gcosmo Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Haifa Ben Abdelouahed
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeAnnihilationModel.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeAnnihilationModel.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeAnnihilationModel.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4PenelopeAnnihilationModel.hh,v 1.1 2008/11/04 10:14:56 pandola Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Luciano Pandola
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeBremsstrahlung.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeBremsstrahlung.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeBremsstrahlung.hh	(revision 1055)
@@ -27,5 +27,5 @@
 // -------------------------------------------------------------------
 // $Id: G4PenelopeBremsstrahlung.hh,v 1.8 2006/06/29 19:36:15 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: L.Pandola
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeBremsstrahlungAngular.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeBremsstrahlungAngular.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeBremsstrahlungAngular.hh	(revision 1055)
@@ -27,5 +27,5 @@
 // -------------------------------------------------------------------
 // $Id: G4PenelopeBremsstrahlungAngular.hh,v 1.3 2006/06/29 19:36:17 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: L.Pandola
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeBremsstrahlungContinuous.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeBremsstrahlungContinuous.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeBremsstrahlungContinuous.hh	(revision 1055)
@@ -27,5 +27,5 @@
 // -------------------------------------------------------------------
 // $Id: G4PenelopeBremsstrahlungContinuous.hh,v 1.4 2008/12/09 15:04:05 pandola Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: L.Pandola
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeCompton.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeCompton.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeCompton.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4PenelopeCompton.hh,v 1.11 2008/03/26 15:30:19 pandola Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Luciano Pandola
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeComptonModel.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeComptonModel.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeComptonModel.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4PenelopeComptonModel.hh,v 1.1 2008/10/28 08:50:21 pandola Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Luciano Pandola
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeGammaConversion.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeGammaConversion.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeGammaConversion.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4PenelopeGammaConversion.hh,v 1.2 2006/06/29 19:36:25 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: L. Pandola
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeGammaConversionModel.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeGammaConversionModel.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeGammaConversionModel.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4PenelopeGammaConversionModel.hh,v 1.1 2008/10/28 08:50:21 pandola Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Luciano Pandola
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeIonisation.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeIonisation.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeIonisation.hh	(revision 1055)
@@ -26,5 +26,5 @@
 // -------------------------------------------------------------------
 // $Id: G4PenelopeIonisation.hh,v 1.5 2006/06/29 19:36:33 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: L. Pandola
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeIonisationModel.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeIonisationModel.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeIonisationModel.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4PenelopeIonisationModel.hh,v 1.1 2008/12/04 14:12:09 pandola Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Luciano Pandola
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopePhotoElectric.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopePhotoElectric.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopePhotoElectric.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4PenelopePhotoElectric.hh,v 1.4 2006/06/29 19:36:35 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: L.Pandola
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopePhotoElectricModel.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopePhotoElectricModel.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopePhotoElectricModel.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4PenelopePhotoElectricModel.hh,v 1.1 2008/10/28 08:50:21 pandola Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Luciano Pandola
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeRayleigh.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeRayleigh.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeRayleigh.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4PenelopeRayleigh.hh,v 1.5 2006/06/29 19:36:37 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Luciano Pandola
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeRayleighModel.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeRayleighModel.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4PenelopeRayleighModel.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4PenelopeRayleighModel.hh,v 1.1 2008/10/28 08:50:21 pandola Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Luciano Pandola
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4RangeNoTest.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4RangeNoTest.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4RangeNoTest.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4RangeNoTest.hh,v 1.4 2006/06/29 19:36:47 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4RangeTest.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4RangeTest.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4RangeTest.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4RangeTest.hh,v 1.4 2006/06/29 19:36:49 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4SemiLogInterpolation.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4SemiLogInterpolation.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4SemiLogInterpolation.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4SemiLogInterpolation.hh,v 1.4 2006/06/29 19:36:51 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4ShellData.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4ShellData.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4ShellData.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4ShellData.hh,v 1.7 2008/03/17 13:45:25 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4ShellEMDataSet.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4ShellEMDataSet.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4ShellEMDataSet.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4ShellEMDataSet.hh,v 1.12 2008/03/17 13:45:25 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4ShellVacancy.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4ShellVacancy.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4ShellVacancy.hh	(revision 1055)
@@ -35,4 +35,5 @@
 //  25 Mar  2002  V.Ivanchenko         Change AverageNOfIonisations int->double
 //  12 Apr  2003  V.Ivanchenko         Migrade to cut per region
+//  16 Apr  2009  V.Ivanchenko         Rename "set" variable
 //
 // -------------------------------------------------------------------
@@ -65,5 +66,5 @@
 						   G4double eLoss) const;
 
-  void AddXsiTable(G4VEMDataSet* set);
+  void AddXsiTable(G4VEMDataSet* p);
 
 private:
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4VCrossSectionHandler.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4VCrossSectionHandler.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4VCrossSectionHandler.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4VCrossSectionHandler.hh,v 1.14 2006/06/29 19:37:01 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4VDataSetAlgorithm.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4VDataSetAlgorithm.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4VDataSetAlgorithm.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4VDataSetAlgorithm.hh,v 1.7 2006/06/29 19:37:07 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4VEMDataSet.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4VEMDataSet.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4VEMDataSet.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4VEMDataSet.hh,v 1.12 2008/03/17 13:45:25 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4VLowEnergyDiscretePhotonProcess.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4VLowEnergyDiscretePhotonProcess.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4VLowEnergyDiscretePhotonProcess.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4VLowEnergyDiscretePhotonProcess.hh,v 1.4 2006/06/29 19:37:13 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // --------------------------------------------------------------
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4VLowEnergyTestableDiscreteProcess.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4VLowEnergyTestableDiscreteProcess.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4VLowEnergyTestableDiscreteProcess.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4VLowEnergyTestableDiscreteProcess.hh,v 1.3 2006/06/29 19:37:17 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4VRangeTest.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4VRangeTest.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4VRangeTest.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4VRangeTest.hh,v 1.3 2006/06/29 19:37:21 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4VeLowEnergyLoss.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4VeLowEnergyLoss.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4VeLowEnergyLoss.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4VeLowEnergyLoss.hh,v 1.9 2006/06/29 19:37:23 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // 3.4.2000 Veronique Lefebure:
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4WaterExcitationStructure.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4WaterExcitationStructure.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4WaterExcitationStructure.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4WaterExcitationStructure.hh,v 1.1 2007/10/15 08:33:25 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // 
 // Contact Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4WaterIonisationStructure.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4WaterIonisationStructure.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4WaterIonisationStructure.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4WaterIonisationStructure.hh,v 1.1 2007/11/08 20:38:40 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // 
 // Contact Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4eBremsstrahlungSpectrum.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4eBremsstrahlungSpectrum.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4eBremsstrahlungSpectrum.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4eBremsstrahlungSpectrum.hh,v 1.8 2006/06/29 19:37:33 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // -------------------------------------------------------------------
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4eCrossSectionExcitationEmfietzoglou.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4eCrossSectionExcitationEmfietzoglou.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4eCrossSectionExcitationEmfietzoglou.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4eCrossSectionExcitationEmfietzoglou.hh,v 1.1 2007/05/02 17:18:48 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // 
 // Contact Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4eCrossSectionScreenedRutherford.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4eCrossSectionScreenedRutherford.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4eCrossSectionScreenedRutherford.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4eCrossSectionScreenedRutherford.hh,v 1.2 2007/10/12 12:26:34 pia Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 // 
 // Contact Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4eIonisationCrossSectionHandler.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4eIonisationCrossSectionHandler.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4eIonisationCrossSectionHandler.hh	(revision 1055)
@@ -24,6 +24,6 @@
 // ********************************************************************
 //
-// $Id: G4eIonisationCrossSectionHandler.hh,v 1.6 2006/06/29 19:37:36 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// $Id: G4eIonisationCrossSectionHandler.hh,v 1.7 2009/01/29 08:13:27 pandola Exp $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // -------------------------------------------------------------------
@@ -40,5 +40,6 @@
 // Modified: 
 // 10 Oct 2001  M.G. Pia        Revision to improve code quality and consistency with design
-//
+// 28 Jan 2009  L.Pandola    Added public method to make a easier migration of
+//                           G4LowEnergyIonisation to G4LivermoreIonisationModel
 // -------------------------------------------------------------------
 
@@ -72,4 +73,8 @@
 
   ~G4eIonisationCrossSectionHandler();
+
+  G4double GetCrossSectionAboveThresholdForElement(G4double energy,
+						   G4double cutEnergy,
+						   G4int Z);
  
 protected:
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4eIonisationParameters.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4eIonisationParameters.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4eIonisationParameters.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4eIonisationParameters.hh,v 1.8 2006/06/29 19:37:38 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Maria Grazia Pia (Maria.Grazia.Pia@cern.ch)
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4eIonisationSpectrum.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4eIonisationSpectrum.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4eIonisationSpectrum.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4eIonisationSpectrum.hh,v 1.7 2006/06/29 19:37:40 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // -------------------------------------------------------------------
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4eLowEnergyLoss.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4eLowEnergyLoss.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4eLowEnergyLoss.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4eLowEnergyLoss.hh,v 1.14 2006/06/29 19:37:42 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // -------------------------------------------------------------------
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4eLowEnergyLoss.icc
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4eLowEnergyLoss.icc	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4eLowEnergyLoss.icc	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4eLowEnergyLoss.icc,v 1.8 2006/06/29 19:37:44 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // ---------------------------------------------------------------
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4ecpssrCrossSection.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4ecpssrCrossSection.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4ecpssrCrossSection.hh	(revision 1055)
@@ -25,5 +25,5 @@
 //
 // $Id: G4ecpssrCrossSection.hh,v 1.3 2008/06/03 07:29:15 gcosmo Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // Author: Haifa Ben Abdelouahed
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4hLowEnergyLoss.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4hLowEnergyLoss.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4hLowEnergyLoss.hh	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4hLowEnergyLoss.hh,v 1.17 2006/06/29 19:37:58 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // $Id: 
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4hLowEnergyLoss.icc
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4hLowEnergyLoss.icc	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4hLowEnergyLoss.icc	(revision 1055)
@@ -26,5 +26,5 @@
 //
 // $Id: G4hLowEnergyLoss.icc,v 1.3 2006/06/29 19:38:00 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 //
 // $Id:
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4hShellCrossSectionDoubleExp.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4hShellCrossSectionDoubleExp.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4hShellCrossSectionDoubleExp.hh	(revision 1055)
@@ -45,5 +45,5 @@
 // -------------------------------------------------------------------
 // $Id: G4hShellCrossSectionDoubleExp.hh,v 1.3 2006/06/29 19:38:12 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4HSHELLCROSSSECTIONDOUBLEEXP_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4hShellCrossSectionDoubleExpData.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4hShellCrossSectionDoubleExpData.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4hShellCrossSectionDoubleExpData.hh	(revision 1055)
@@ -40,5 +40,5 @@
 // -------------------------------------------------------------------
 // $Id: G4hShellCrossSectionDoubleExpData.hh,v 1.3 2006/06/29 19:38:14 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4hShellCrossSectionDoubleExpData_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4hShellCrossSectionExp.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4hShellCrossSectionExp.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4hShellCrossSectionExp.hh	(revision 1055)
@@ -45,5 +45,5 @@
 // -------------------------------------------------------------------
 // $Id: G4hShellCrossSectionExp.hh,v 1.3 2006/06/29 19:38:16 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4HSHELLCROSSSECTIONEXP_HH
Index: trunk/source/processes/electromagnetic/lowenergy/include/G4hShellCrossSectionExpData.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4hShellCrossSectionExpData.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4hShellCrossSectionExpData.hh	(revision 1055)
@@ -38,5 +38,5 @@
 // -------------------------------------------------------------------
 // $Id: G4hShellCrossSectionExpData.hh,v 1.3 2006/06/29 19:38:18 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-beta-cand-00 $
 
 #ifndef G4hShellCrossSectionExpData_HH

Index: trunk/source/processes/electromagnetic/lowenergy/include/G4IonParametrisedLossModel.hh
===================================================================
--- trunk/source/processes/electromagnetic/lowenergy/include/G4IonParametrisedLossModel.hh	(revision 1014)
+++ trunk/source/processes/electromagnetic/lowenergy/include/G4IonParametrisedLossModel.hh	(revision 1055)
@@ -37,7 +37,10 @@
 // First implementation: 10. 11. 2008
 //
-// Modifications:
-//
-//
+// Modifications: 03. 02. 2009 - Bug fix iterators (AL)
+//                11. 03. 2009 - Introduced new table handler (G4IonDEDXHandler)
+//                               and modified method to add/remove tables 
+//                               (tables are now built in initialisation phase),
+//                               Minor bug fix in ComputeDEDXPerVolume (AL) 
+// 
 // Class description:
 //    Model for computing the energy loss of ions by employing a 
@@ -57,6 +60,5 @@
 #include "G4VEmModel.hh"
 #include "G4EmCorrections.hh"
-#include "G4IonParametrisedLossTable.hh"
-#include "G4EmCorrections.hh"
+#include "G4IonDEDXHandler.hh"
 #include <iomanip>
 #include <list>
@@ -67,6 +69,9 @@
 class G4BetheBlochModel;
 class G4ParticleChangeForLoss;
-
-typedef std::list<G4IonLossTableHandle*> LossTableList;
+class G4VIonDEDXTable;
+class G4VIonDEDXScalingAlgorithm;
+class G4LPhysicsFreeVector;
+
+typedef std::list<G4IonDEDXHandler*> LossTableList;
 typedef std::pair<const G4ParticleDefinition*, const G4Material*> IonMatCouple;
 
@@ -150,28 +155,18 @@
 				 G4double); // Length of current step
 
-
-   // Template function which allows to add additional stopping power tables
+   G4double GetRange(const G4ParticleDefinition*, // Projectile
+		     const G4Material*,           // Target Material
+	             G4double);                   // Kinetic energy
+
+   // Function which allows to add additional stopping power tables
    // in combination with a scaling algorithm, which may depend on dynamic
    // information like the current particle energy (the table and scaling 
-   // algorithm are used via a wrapper class, which performs e.g.caching or
+   // algorithm are used via a handler class, which performs e.g.caching or
    // which applies the scaling of energy and dE/dx values)
-   template <class TABLE, class SCALING_ALGO>
-   void AddDEDXTable() {
-       G4IonLossTableHandle* table =
-               new G4IonParametrisedLossTable<TABLE, SCALING_ALGO>;      
- 
-       lossTableList.push_front(table);
-   }
-
-   // Template function which allows to add additional stopping power tables
-   // (the table itself is used via a wrapper class, which performs e.g.
-   // caching)
-   template <class TABLE>
-   void AddDEDXTable() {
-       G4IonLossTableHandle* table =
-               new G4IonParametrisedLossTable<TABLE>;      
- 
-       lossTableList.push_front(table);
-   }
+   G4bool AddDEDXTable(const G4String& name,
+                     G4VIonDEDXTable* table, 
+                     G4VIonDEDXScalingAlgorithm* algorithm = 0); 
+
+   G4bool RemoveDEDXTable(const G4String& name); 
 
    // Function checking the applicability of physics tables to ion-material
@@ -184,4 +179,14 @@
    // and a specified energy grid 
    void PrintDEDXTable(
+                      const G4ParticleDefinition*,  // Projectile (ion) 
+                      const G4Material*, // Absorber material
+                      G4double,          // Minimum energy per nucleon
+                      G4double,          // Maximum energy per nucleon
+                      G4int,             // Number of bins
+                      G4bool);           // Logarithmic scaling of energy
+
+   // Function printing a dE/dx table for a given ion-material combination
+   // and a specified energy grid 
+   void PrintDEDXTableHandlers(
                       const G4ParticleDefinition*,  // Projectile (ion) 
                       const G4Material*, // Absorber material